Payment class
Constructors
-
Payment({String? description, required List<
Destination> destinations, DateTime? createdAt, int ttl = 0, String? metadata, String? platform, String? platformLogoUrl, String? platformLogoLightUrl, Platform? parentPlatform, Platform? childPlatform, String? btcPayServerPluginVersion}) -
Payment.fromJson(Map<
String, dynamic> json) -
factory
Properties
- btcPayServerPluginVersion ↔ String?
-
getter/setter pair
- childPlatform ↔ Platform?
-
getter/setter pair
- createdAt ↔ DateTime?
-
getter/setter pair
- description ↔ String?
-
getter/setter pair
-
destinations
↔ List<
Destination> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isMetadataDecrypted ↔ bool
-
Runtime-only flag set by BrantaService after metadata decryption.
Not serialized to/from JSON.
getter/setter pair
- metadata ↔ String?
-
getter/setter pair
- parentPlatform ↔ Platform?
-
getter/setter pair
- platform ↔ String?
-
getter/setter pair
- platformLogoLightUrl ↔ String?
-
getter/setter pair
- platformLogoUrl ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ttl ↔ int
-
getter/setter pair
Methods
-
getDefaultValue(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited