Payment class
- Annotations
-
- @JsonSerializable.new()
Constructors
Properties
- createdDate → DateTime?
-
final
- description ↔ String?
-
getter/setter pair
-
destinations
→ List<
Destination> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata ↔ String?
-
getter/setter pair
- platform → String?
-
final
- platformLogoUrl → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ttl ↔ int?
-
getter/setter pair
- verifyUrl ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited