PaymentBuilder class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addDestination(
String address, {DestinationType? type}) → PaymentBuilder -
addMetadata(
String key, String value) → PaymentBuilder -
build(
) → Payment -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setChildPlatform(
String name, {String? logoUrl, String? logoLightUrl}) → PaymentBuilder -
setDescription(
String description) → PaymentBuilder -
setPlatformLogoUrl(
String platformLogoUrl) → PaymentBuilder -
setTtl(
int ttl) → PaymentBuilder -
setZk(
) → PaymentBuilder -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited